@@ -3,10 +3,17 @@
 
 #define LIQAPP_HILDON_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 int liqapp_hildon_init();
 
 int liqapp_hildon_close();
 
+#ifdef __cplusplus
+}
+#endif
+
 
 #endif
