@@ -2,6 +2,10 @@
 #ifndef liqcell_EASYPAINT_H
 #define liqcell_EASYPAINT_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include "liqbase.h"
 #include "liqcell.h"
 
@@ -11,9 +15,10 @@ void liqcell_easypaint(liqcell *self,liqcliprect *cr,    int x,int y,    int w,i
 
 int liqcell_threadloadimage(liqcell *self);		// start the thread running loading am image
 
+unsigned int decodecolor(const char *source,unsigned char *ry,unsigned char *ru,unsigned char *rv,unsigned char *ra,unsigned char *rc);
 
-
-
-// liqcell_propseti(  self ,  "imagefloat", "yes" );
+#ifdef __cplusplus
+}
+#endif
 
 #endif
