@@ -1,7 +1,9 @@
 #ifndef LIQX11INFO_H
 #define LIQX11INFO_H
 
-
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -65,8 +67,10 @@ int liqx11info_eventgetnext(liqx11info *myx11info,XEvent *event);
 
 int liqx11info_get_next_liqevent(liqx11info *myx11info,LIQEVENT *ev,int *dirtyflagptr);
 
+int liqx11info_minimize(liqx11info *myx11info);
 
-
-
+#ifdef __cplusplus
+}
+#endif
 
 #endif
