@@ -1,7 +1,9 @@
 #ifndef LIQX11OVERLAY_H
 #define LIQX11OVERLAY_H
 
-
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -51,18 +53,15 @@ typedef struct liqx11overlay
 
 
 
-int liqx11overlay_init(liqx11overlay *self, Display *dpy, int screen, Window window, GC gc);
+int liqx11overlay_init(liqx11overlay *self, Display *dpy, int screen, Window window, GC gc,   int attrswidth,int attrsheight);
 int liqx11overlay_show(liqx11overlay *self);
 int liqx11overlay_hide(liqx11overlay *self);
 int liqx11overlay_close(liqx11overlay *self);
 int liqx11overlay_refreshdisplay(liqx11overlay *self);
 int liqx11overlay_drawcolorcube(liqx11overlay *self,int x,int y,char grey);
 
-
-
-
-
-
-
+#ifdef __cplusplus
+}
+#endif
 
 #endif
