@@ -6,6 +6,25 @@
 #include "liqcell_easyrun.h"
 #include "liqcell_easyhandler.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+
+	int dialog_selectimage_grid_getfirstphoto_filename(liqcell *self,char *buffer,int bufferlen);
+	int dialog_selectimage_grid_getselectedphoto_filename(liqcell *self,char *buffer,int bufferlen);
+	int dialog_selectimage_grid_selectall(liqcell *self);
+	int dialog_selectimage_grid_selectnone(liqcell *self);
+	int dialog_selectimage_grid_selectinv(liqcell *self);
+
+
+	int dialog_selectimage_getfirstphoto_filename(liqcell *self,char *buffer,int bufferlen)
+    {
+		liqcell *dialog_selectimage_grid1 = liqcell_child_lookup(self, "dialog_selectimage_grid1");
+		
+		return dialog_selectimage_grid_getfirstphoto_filename(dialog_selectimage_grid1,buffer,bufferlen);
+	}
+	
 
 
     // todo, move this into the lib at earliest opportunity
@@ -108,6 +127,22 @@ static int dialog_selectimage_dialog_close(liqcell *self,liqcelleventargs *args,
  */	
 static int dialog_selectimage_shown(liqcell *self,liqcelleventargs *args, liqcell *context)
 {
+	// make sure we advance the multiselect stuff
+	liqcell *dialog_selectimage_grid1 = liqcell_child_lookup(self, "dialog_selectimage_grid1");
+	liqcell *cmdall = liqcell_child_lookup(self, "cmdall");
+	liqcell *cmdnone = liqcell_child_lookup(self, "cmdnone");
+	liqcell *cmdinv = liqcell_child_lookup(self, "cmdinv");
+	
+	int ismultiselect = liqcell_propgeti(self,"multiselect",0);
+	
+	liqcell_setvisible(cmdall,ismultiselect);
+	liqcell_setvisible(cmdinv,ismultiselect);
+	liqcell_setvisible(cmdnone,ismultiselect);
+	
+	liqcell_propseti( dialog_selectimage_grid1,"multiselect",ismultiselect);
+	
+	
+	
 	return 0;
 }
 /**	
@@ -155,13 +190,34 @@ static int dialog_selectimage_resize(liqcell *self,liqcelleventargs *args, liqce
 	float sy=((float)self->h)/((float)self->innerh);
 	
 	liqcell *cmdselect = liqcell_child_lookup(self, "cmdselect");
-	liqcell *liqrecentphotoselect1 = liqcell_child_lookup(self, "liqrecentphotoselect1");
+	liqcell *dialog_selectimage_grid1 = liqcell_child_lookup(self, "dialog_selectimage_grid1");
+
+	liqcell *cmdall = liqcell_child_lookup(self, "cmdall");
+	liqcell *cmdnone = liqcell_child_lookup(self, "cmdnone");
+	liqcell *cmdinv = liqcell_child_lookup(self, "cmdinv");
 	liqcell *title = liqcell_child_lookup(self, "title");
-	liqcell_setrect_autoscale( cmdselect, 580,420, 220,60, sx,sy);
-	liqcell_setrect_autoscale( liqrecentphotoselect1, 0,58, 800,420, sx,sy);
+	liqcell_setrect_autoscale( cmdselect, 580,420, 100,60, sx,sy);
+	liqcell_setrect_autoscale( cmdall,  470,420, 100,60, sx,sy);
+	liqcell_setrect_autoscale( cmdnone, 370,420, 100,60, sx,sy);
+	liqcell_setrect_autoscale( cmdinv, 270,420, 220,60, sx,sy);
+	liqcell_setrect_autoscale( dialog_selectimage_grid1, 0,58, 800,420, sx,sy);
 	liqcell_setrect_autoscale( title, 0,0, 800,56, sx,sy);
 	return 0;
 }
+/**	
+ * dialog_selectimage.cmdcamera clicked
+ */	
+static int cmdcamera_click(liqcell *self,liqcelleventargs *args, liqcell *dialog_selectimage)
+{
+    // bring up camera ui :D
+
+	liqcell *dialog = liqcell_quickcreatevis("cameraui", "liqcam", 0,0, -1,-1);
+	liqcell_easyrun(dialog);
+	liqcell_release(dialog);
+	liqcell_handlerrun(dialog_selectimage,"refresh",NULL);
+
+	return 0;
+}
 
 /**	
  * dialog_selectimage.cmdselect clicked
@@ -170,18 +226,18 @@ static int cmdselect_click(liqcell *self,liqcelleventargs *args, liqcell *dialog
 {
     // we are done here.
 
-    liqcell *liqrecentphotoselect1 = liqcell_child_lookup(dialog_selectimage, "liqrecentphotoselect1");
+    liqcell *dialog_selectimage_grid1 = liqcell_child_lookup(dialog_selectimage, "dialog_selectimage_grid1");
     
            //########## major sideways hack.  classes need declarations and header files.
-            int liqrecentphotoselect_getselectedphoto_filename(liqcell *self,char *buffer,int bufferlen);
+            int dialog_selectimage_grid_getselectedphoto_filename(liqcell *self,char *buffer,int bufferlen);
             char selfn[FILENAME_MAX]={0};
-            liqrecentphotoselect_getselectedphoto_filename(liqrecentphotoselect1,selfn,sizeof(selfn) );
+            dialog_selectimage_grid_getselectedphoto_filename(dialog_selectimage_grid1,selfn,sizeof(selfn) );
 
-            //liqapp_log("selimg a %s",selfn);
+            liqapp_log("selimg a %s",selfn);
             
             //char *selfn=liqcell_propgets(  oneedit, "imagefilenameselected",NULL );
             
-            if( selfn && *selfn )
+            if( *selfn )
             {
                 liqapp_log("selimg got sel %s",selfn);
                 liqcell_propsets(  dialog_selectimage, "imagefilenameselected", selfn  );               
@@ -191,20 +247,37 @@ static int cmdselect_click(liqcell *self,liqcelleventargs *args, liqcell *dialog
     liqcell_setvisible(dialog_selectimage,0);
 	return 0;
 }
+
+
 /**	
- * dialog_selectimage_child_test_seek this function shows how to access members
+ * dialog_selectimage.cmdall clicked
  */	
-	  
-static void dialog_selectimage_child_test_seek(liqcell *self)
-{	  
-	liqcell *cmdselect = liqcell_child_lookup(self, "cmdselect");
-	liqcell *liqrecentphotoselect1 = liqcell_child_lookup(self, "liqrecentphotoselect1");
-	liqcell *title = liqcell_child_lookup(self, "title");
+static int cmdall_click(liqcell *self,liqcellclickeventargs *args, liqcell *dialog_selectimage)
+{
+    liqcell *dialog_selectimage_grid1 = liqcell_child_lookup(dialog_selectimage, "dialog_selectimage_grid1");
+	dialog_selectimage_grid_selectall(dialog_selectimage_grid1);
+	return 0;
+}
+/**	
+ * dialog_selectimage.cmdnone clicked
+ */	
+static int cmdnone_click(liqcell *self,liqcellclickeventargs *args, liqcell *dialog_selectimage)
+{
+    liqcell *dialog_selectimage_grid1 = liqcell_child_lookup(dialog_selectimage, "dialog_selectimage_grid1");
+	dialog_selectimage_grid_selectnone(dialog_selectimage_grid1);
+	return 0;
 }
 
+/**	
+ * dialog_selectimage.cmdinv clicked
+ */	
+static int cmdinv_click(liqcell *self,liqcellclickeventargs *args, liqcell *dialog_selectimage)
+{
+    liqcell *dialog_selectimage_grid1 = liqcell_child_lookup(dialog_selectimage, "dialog_selectimage_grid1");
+	dialog_selectimage_grid_selectinv(dialog_selectimage_grid1);
+	return 0;
+}
 
-	
-    
 //#####################################################################
 //#####################################################################
 //#####################################################################
@@ -240,8 +313,8 @@ static void dialog_selectimage_child_test_seek(liqcell *self)
 		}
         */
         
-        liqcell *liqrecentphotoselect1=liqcell_child_lookup(dialog_selectimage,"liqrecentphotoselect1");
-        liqcell_filter_run(liqrecentphotoselect1,searchterm);
+        liqcell *dialog_selectimage_grid1=liqcell_child_lookup(dialog_selectimage,"dialog_selectimage_grid1");
+        liqcell_filter_run(dialog_selectimage_grid1,searchterm);
         
         /*
         liqcell *searchinprogress = liqcell_child_lookup(body,"searchinprogress");
@@ -328,7 +401,6 @@ liqcell *dialog_selectimage_create()
 	// Optimization:  defaults: background, prefer nothing, will be shown through if there is a wallpaper
 	// Optimization:  defaults: text, white, very fast rendering
 
-
 	//############################# title:label
 	liqcell *title = liqcell_quickcreatevis("title", "label", 0, 0, 800, 56);
 	liqcell_setfont(	title, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (29), 0) );
@@ -337,18 +409,76 @@ liqcell *dialog_selectimage_create()
 	liqcell_propsets(  title, "backcolor", "xrgb(0,0,0)" );
 	liqcell_propseti(  title, "textalign", 0 );
 	liqcell_child_append(  self, title);
-	//############################# liqrecentphotoselect1:liqrecentphotos
-	liqcell *liqrecentphotoselect1 = liqcell_quickcreatevis("liqrecentphotoselect1", "liqrecentphotoselect", 0, 58, 800, 420);
-	liqcell_child_append(  self, liqrecentphotoselect1);
+	//############################# dialog_selectimage_grid1:liqrecentphotos
+	liqcell *dialog_selectimage_grid1 = liqcell_quickcreatevis("dialog_selectimage_grid1", "dialog_selectimage_grid", 0, 58, 800, 420);
+	liqcell_propseti(  dialog_selectimage_grid1, "multiselect", 1 );
+	liqcell_child_append(  self, dialog_selectimage_grid1);
+    //############################# cmdcamera:commandbutton
+	liqcell *cmdcamera = liqcell_quickcreatevis("cmdcamera", "commandbutton", 500, 0, 200, 56);
+	liqcell_setfont(	cmdcamera, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (29), 0) );
+	liqcell_setcaption(cmdcamera, "camera" );
+	liqcell_propsets(  cmdcamera, "textcolor", "rgb(255,255,255)" );
+	liqcell_propsets(  cmdcamera, "backcolor", "xrgb(0,0,64)" );
+	liqcell_propsets(  cmdcamera, "bordercolor", "rgb(255,255,255)" );
+	liqcell_propseti(  cmdcamera, "textalign",  2 );
+	liqcell_propseti(  cmdcamera, "textaligny", 2 );
+	liqcell_handleradd_withcontext(cmdcamera, "click", (void*)cmdcamera_click, self );
+    //liqcell_setenabled(cmdcamera,0);
+	liqcell_child_append(  self, cmdcamera);
+    	
+
+
+
+	//############################# cmdall:label
+	liqcell *cmdall = liqcell_quickcreatevis("cmdall", "label", 470, 420,100,60);
+	liqcell_setfont(	cmdall, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (29), 0) );
+	liqcell_setcaption(cmdall, "all" );
+	liqcell_propsets(  cmdall, "textcolor", "rgb(255,255,255)" );
+	liqcell_propsets(  cmdall, "backcolor", "xrgb(0,64,64)" );
+	liqcell_propsets(  cmdall, "bordercolor", "rgb(255,255,255)" );
+	liqcell_propseti(  cmdall, "textalign", 2 );
+	liqcell_propseti(  cmdall, "textaligny", 2 );
+	liqcell_handleradd_withcontext(cmdall, "click", (void*)cmdall_click, self );
+	liqcell_child_append(  self, cmdall);
+	//############################# cmdnone:label
+	liqcell *cmdnone = liqcell_quickcreatevis("cmdnone", "label", 370, 420,100,60);
+	liqcell_setfont(	cmdnone, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (29), 0) );
+	liqcell_setcaption(cmdnone, "none" );
+	liqcell_propsets(  cmdnone, "textcolor", "rgb(255,255,255)" );
+	liqcell_propsets(  cmdnone, "backcolor", "xrgb(0,64,64)" );
+	liqcell_propsets(  cmdnone, "bordercolor", "rgb(255,255,255)" );
+	liqcell_propseti(  cmdnone, "textalign", 2 );
+	liqcell_propseti(  cmdnone, "textaligny", 2 );
+	liqcell_handleradd_withcontext(cmdnone, "click", (void*)cmdnone_click, self );
+	liqcell_child_append(  self, cmdnone);
+	//############################# cmdinv:label
+	liqcell *cmdinv = liqcell_quickcreatevis("cmdinv", "label", 270, 420,100,60);
+	liqcell_setfont(	cmdinv, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (29), 0) );
+	liqcell_setcaption(cmdinv, "inv" );
+	liqcell_propsets(  cmdinv, "textcolor", "rgb(255,255,255)" );
+	liqcell_propsets(  cmdinv, "backcolor", "xrgb(0,64,64)" );
+	liqcell_propsets(  cmdinv, "bordercolor", "rgb(255,255,255)" );
+	liqcell_propseti(  cmdinv, "textalign", 2 );
+	liqcell_propseti(  cmdinv, "textaligny", 2 );
+	liqcell_handleradd_withcontext(cmdinv, "click", (void*)cmdinv_click, self );
+	liqcell_child_append(  self, cmdinv);
+	
+	
+		
+	
+	
+	
+	
     //############################# cmdselect:commandbutton
-	liqcell *cmdselect = liqcell_quickcreatevis("cmdselect", "commandbutton", 580, 420, 220, 60);
+	liqcell *cmdselect = liqcell_quickcreatevis("cmdselect", "commandbutton", 580, 420, 210, 60);
 	liqcell_setfont(	cmdselect, liqfont_cache_getttf("/usr/share/fonts/nokia/nosnb.ttf", (29), 0) );
 	liqcell_setcaption(cmdselect, "Select" );
 	liqcell_propsets(  cmdselect, "textcolor", "rgb(255,255,255)" );
 	liqcell_propsets(  cmdselect, "backcolor", "xrgb(0,64,0)" );
 	liqcell_propsets(  cmdselect, "bordercolor", "rgb(255,255,255)" );
-	liqcell_propseti(  cmdselect, "textalign", 2 );
-	liqcell_handleradd_withcontext(cmdselect, "click", cmdselect_click, self );
+	liqcell_propseti(  cmdselect, "textalign",  2 );
+	liqcell_propseti(  cmdselect, "textaligny", 2 );
+	liqcell_handleradd_withcontext(cmdselect, "click", (void*)cmdselect_click, self );
     //liqcell_setenabled(cmdselect,0);
 	liqcell_child_append(  self, cmdselect);
     
@@ -358,29 +488,33 @@ liqcell *dialog_selectimage_create()
 		liqcell_setcaption(search, "" );
 		liqcell_propsets(  search, "textcolor",   "rgb(255,255,255)" );
 		liqcell_propsets(  search, "backcolor",   "xrgb(100,140,100)" );
-		liqcell_handleradd_withcontext( search,    "click",           search_click,  self );
-		liqcell_handleradd_withcontext( search,    "captionchange",   search_change, self );
+		liqcell_handleradd_withcontext( search,    "click",           (void*)search_click,  self );
+		liqcell_handleradd_withcontext( search,    "captionchange",   (void*)search_change, self );
 		liqcell_setvisible(search,0);		// watch this!
 		liqcell_child_append( self, search );
 		
-		//liqcell_handleradd_withcontext(body,    "keypress",   dialog_selectimage_keypress,  self);
-		//liqcell_handleradd_withcontext(body,    "keyrelease", dialog_selectimage_keyrelease,self);
-		liqcell_handleradd_withcontext(self,    "keypress",   dialog_selectimage_keypress,  self);
-		liqcell_handleradd_withcontext(self,    "keyrelease", dialog_selectimage_keyrelease,self);
- 		liqcell_handleradd_withcontext(self,    "paint",      dialog_selectimage_paint,  	self);
+		liqcell_handleradd_withcontext(self,    "keypress",   (void*)dialog_selectimage_keypress,  self);
+		liqcell_handleradd_withcontext(self,    "keyrelease", (void*)dialog_selectimage_keyrelease,self);
+ 		liqcell_handleradd_withcontext(self,    "paint",      (void*)dialog_selectimage_paint,  	self);
         
     
     //liqcell_propsets(  self, "backcolor", "rgb(0,0,0)" );
-	liqcell_handleradd_withcontext(self, "refresh", dialog_selectimage_refresh ,self);
-	liqcell_handleradd_withcontext(self, "shown", dialog_selectimage_shown ,self);
-	liqcell_handleradd_withcontext(self, "resize", dialog_selectimage_resize ,self);
-	//liqcell_handleradd_withcontext(self, "keypress", dialog_selectimage_keypress,self );
-	//liqcell_handleradd_withcontext(self, "keyrelease", dialog_selectimage_keyrelease ,self);
-	liqcell_handleradd_withcontext(self, "mouse", dialog_selectimage_mouse,self );
-	liqcell_handleradd_withcontext(self, "click", dialog_selectimage_click ,self);
-	//liqcell_handleradd_withcontext(self, "paint", dialog_selectimage_paint ,self); // use only if required, heavyweight
-	liqcell_handleradd_withcontext(self, "dialog_open", dialog_selectimage_dialog_open ,self);
-	liqcell_handleradd_withcontext(self, "dialog_close", dialog_selectimage_dialog_close ,self);
+	liqcell_handleradd_withcontext(self, "refresh", (void*)dialog_selectimage_refresh ,self);
+	liqcell_handleradd_withcontext(self, "shown", (void*)dialog_selectimage_shown ,self);
+	liqcell_handleradd_withcontext(self, "resize", (void*)dialog_selectimage_resize ,self);
+	liqcell_handleradd_withcontext(self, "mouse", (void*)dialog_selectimage_mouse,self );
+	liqcell_handleradd_withcontext(self, "click", (void*)dialog_selectimage_click ,self);
+	liqcell_handleradd_withcontext(self, "dialog_open", (void*)dialog_selectimage_dialog_open ,self);
+	liqcell_handleradd_withcontext(self, "dialog_close", (void*)dialog_selectimage_dialog_close ,self);
+	
+	
+	// allow the image thumbnails to be lazyloaded :)  (test for burchr)
+	liqcell_propseti(self,"idle_lazyrun_wanted",1);
+	
 	return self;
 }
 
+#ifdef __cplusplus
+}
+#endif
+
