@@ -42,6 +42,10 @@
 #include "liqcliprect.h"
 //#include "liqcanvas_xv.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 
 
 int liqcanvas_firstrun_splash();
@@ -54,8 +58,7 @@ int           liqcanvas_nextevent_x11(LIQEVENT *ev,int *dirtyflagptr);
 
 
 
-//#include "liq_xsurface.h"			// include available workhorse functions
-
+#include "liq_xsurface.h"			// include available workhorse functions
 
 //todo: make this a class instance, we might end up having multiple canvases..
 liqcanvas canvas={0,0};
@@ -89,7 +92,7 @@ int liqcanvas_takepicture()
 							if(!imgfrom)
 							{
 								// camera not on, we are doing desktop
-								imgfrom = canvas.surface;
+								imgfrom = canvas.rotation_native_surface;//canvas.surface;
 							}
 							if(imgfrom)
 							{
@@ -139,6 +142,7 @@ int liqcanvas_settitle(char *newtitle)
     
     XSetStandardProperties(liqcanvas_getx11info()->mydisplay, liqcanvas_getx11info()->mywindow, newtitle,
             newtitle, None, NULL, 0, NULL);
+    return 0;
 }
 
 
@@ -188,6 +192,8 @@ int liqcanvas_init_inner(int pixelwidth,int pixelheight,int fullscreen)
 		
 	}
 	
+	liqapp_log("liqcanvas_init_inner start wh %d,%d",pixelwidth,pixelheight);
+	
 	canvas.x11info =(void*)&x11infobase;
 	
 	
@@ -211,6 +217,8 @@ int liqcanvas_init_inner(int pixelwidth,int pixelheight,int fullscreen)
 		
 	}
 	
+	canvas.rotation_angle=0;
+	
 
 	canvas.keepalivealarmtime=10000;
 	canvas.pixelwidth = pixelwidth;
@@ -252,7 +260,8 @@ int liqcanvas_init_inner(int pixelwidth,int pixelheight,int fullscreen)
 	//#################################################
 	
 	liqapp_log("Canvas.dpi %i,%i",canvas.dpix,canvas.dpiy);
-	
+	liqapp_log("liqcanvas_init_inner -  canvas.  wh %d,%d   surface wh %d,%d rotnat wh %d,%d",canvas.pixelwidth,canvas.pixelheight,  canvas.rotation_native_surface->width,canvas.rotation_native_surface->height,  canvas.surface->width,canvas.surface->height );
+	liqapp_log("liqcanvas_init_inner complete wh %d,%d",canvas.pixelwidth,canvas.pixelheight);
 
 	return 0;
 }
@@ -274,6 +283,9 @@ int liqcanvas_init(int pixelwidth,int pixelheight,int fullscreen)
 		return -1;
 		
 	}
+	
+	liqapp_log("liqcanvas_init start wh %d,%d",pixelwidth,pixelheight);
+	
 	if(liqcanvas_init_inner(pixelwidth,pixelheight,fullscreen)!=0)
 	{
 		{ liqapp_errorandfail(-1,"canvas liqx11info_init failed"); }
@@ -320,6 +332,7 @@ int liqcanvas_init(int pixelwidth,int pixelheight,int fullscreen)
 		// opened again!
 		// 20090511_023909 lcuk : user hopefully wont have problems now :)
 	}
+	liqapp_log("liqcanvas_init complete wh %d,%d",canvas.pixelwidth,canvas.pixelheight);
 	return 0;
 		
 
@@ -429,6 +442,8 @@ int liqcanvas_refreshdisplay()
 	
 	liqx11info_refreshdisplay( liqcanvas_getx11info() );
 	
+	canvas.framecount++;
+	
 	return 0;
 }
 
@@ -437,6 +452,10 @@ int liqcanvas_refreshdisplay()
 int liqcanvas_minimize()
 {
 	//liqcanvas_xv_minimize();
+	
+	
+	liqx11info_minimize(  liqcanvas_getx11info() );
+	
 	return 0;
 }
 
@@ -447,23 +466,7 @@ int liqcanvas_minimize()
 //##########################################################################
 //##########################################################################
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
+#ifdef __cplusplus
+}
+#endif
 
