@@ -22,7 +22,6 @@
  *
  */
 
-#define _GNU_SOURCE
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -38,7 +37,7 @@
 #include <unistd.h>
 #include <errno.h>
 
-
+#include <pthread.h>
 
 #include <time.h>			// req for sleep
 #include <sys/time.h>		// req for getticks
@@ -50,14 +49,17 @@
 #include "liqcell.h"
 #include "liqcell_prop.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 
-char*  liqcell_local_lookup_getname(liqcell *self,char *name)
+char*  liqcell_local_lookup_getname(liqcell *self, const char *name)
 {
 	liqcell *c = liqcell_local_lookup(self,name);
 	if(c) return liqcell_getname(c);
 	return NULL;
 }
-char*  liqcell_local_lookup_getcaption(liqcell *self,char *name)
+char*  liqcell_local_lookup_getcaption(liqcell *self, const char *name)
 {
 	liqcell *c = liqcell_local_lookup(self,name);
 	if(c) return liqcell_getcaption(c);
@@ -148,7 +150,7 @@ void liqcell_free(liqcell *self)
     if( self->classname && (strcmp(self->classname,"liqtimer")==0) )
     {
         // cheat to close down the thread!
-        pthread_t 		*tid = liqcell_getdata(self);
+        pthread_t 		*tid = (pthread_t *)liqcell_getdata(self);
         if(tid)
         {
             // only live once...
@@ -497,7 +499,7 @@ int    	liqcell_getdirty(liqcell *self)
  * @param self The liqcell to modify
  * @param name The name of the liqcell
  */
-void liqcell_setname(liqcell *self,char *name)
+void liqcell_setname(liqcell *self, const char *name)
 {
 	if(self->name)
 	{
@@ -512,7 +514,7 @@ void liqcell_setname(liqcell *self,char *name)
  * @param self The liqcell to modify
  * @param caption The caption of the liqcell
  */
-void liqcell_setcaption(liqcell *self,char *caption)
+void liqcell_setcaption(liqcell *self, const char *caption)
 {
 	// 20090626_213441 lcuk : did some extra logging for zachmon's benefit
 	if(!self)
@@ -541,7 +543,7 @@ void liqcell_setcaption(liqcell *self,char *caption)
 //############################################################# 
 
 /** Helper function for liqcell_setcaption */
-void liqcell_setcaption_vprintf(liqcell *self,char *format, va_list arg)
+void liqcell_setcaption_vprintf(liqcell *self, const char *format, va_list arg)
 {
     //time_t     now;
     //struct tm  *ts;
@@ -553,7 +555,7 @@ void liqcell_setcaption_vprintf(liqcell *self,char *format, va_list arg)
 /**
  * Set formatted string prop and 
  */
-void liqcell_setcaption_printf(liqcell *self,char *format, ...)
+void liqcell_setcaption_printf(liqcell *self, const char *format, ...)
 {
 	va_list arg;
 	va_start(arg, format);
@@ -572,7 +574,7 @@ void liqcell_setcaption_printf(liqcell *self,char *format, ...)
  * @param self The liqcell to modify
  * @param classname The classname of the liqcell
  */
-void liqcell_setclassname(liqcell *self,char *classname)
+void liqcell_setclassname(liqcell *self, const char *classname)
 {
 	if(self->classname)
 	{
@@ -587,7 +589,7 @@ void liqcell_setclassname(liqcell *self,char *classname)
  * @param self The liqcell to modify
  * @param context The context of the liqcell
  */
-void liqcell_setcontext(liqcell *self,char *context)
+void liqcell_setcontext(liqcell *self, const char *context)
 {
 	if(self->context)
 	{
@@ -1199,6 +1201,9 @@ int    	liqcell_getinnerh(liqcell *self)
 }
 
 
+
+
+
 //#########################################################################
 //#########################################################################
 //######################################################################### cell linkage
@@ -1394,6 +1399,24 @@ int liqcell_child_removeallvisual(liqcell *self)
 	return 0;
 }
 
+/**
+ * Remove all children of a specified class
+ * @param self The liqcell to remove the children of
+ * @return int Success or Failure
+ */
+int liqcell_child_removeallclass(liqcell *self, char *classname)
+{
+	liqcell *c=liqcell_getlinkchild(self);
+	while(  c   )
+	{
+		liqcell *d = c->linknext;
+		if( liqcell_isclass(c,classname) ) liqcell_child_remove(self,c);
+		c=d;
+	}
+	return 0;
+}
+
+
 /**
  * Remove a child from the provided parent
  * @param self The parent to remove the child from
@@ -1598,7 +1621,7 @@ liqcell* liqcell_child_insertsortedbyname(liqcell *self,liqcell * ch,int sortpos
  * @param name The name of the child to find
  * @return liqcell* The found child or NULL
  */
-liqcell* liqcell_child_lookup_simple(liqcell *self,char *name)
+liqcell* liqcell_child_lookup_simple(liqcell *self, const char *name)
 {
 	// 20090615_031345 lcuk : ignore dot name in this variation
 
@@ -1621,10 +1644,10 @@ liqcell* liqcell_child_lookup_simple(liqcell *self,char *name)
  * @param name The name of the child to find
  * @return liqcell* The found child or NULL
  */
-liqcell* liqcell_child_lookup(liqcell *self,char *name)
+liqcell* liqcell_child_lookup(liqcell *self, const char *name)
 {
 	// find a named child
-	char *dot=strchr(name,'.');
+	const char *dot=strchr(name,'.');
 	if(dot)
 	{
 		//liqapp_log("dot1 %s",dot);
@@ -1672,7 +1695,7 @@ liqcell* liqcell_child_lookup(liqcell *self,char *name)
  * @param classname The classname
  * @return liqcell* The found liqcell or NULL
  */
-liqcell*  liqcell_child_lookup_nameclass(liqcell *self,char *name,char *classname)
+liqcell*  liqcell_child_lookup_nameclass(liqcell *self, const char *name, const char *classname)
 {
 	//liqapp_log("find a child called '%s:%s'",name,classname);
 	liqcell *c=self->linkchild;
@@ -1694,7 +1717,7 @@ liqcell*  liqcell_child_lookup_nameclass(liqcell *self,char *name,char *classnam
  * @param name The name of the child to find
  * @return liqcell* The found child or NULL
  */
-liqcell *liqcell_local_lookup(liqcell *self,char *name)
+liqcell *liqcell_local_lookup(liqcell *self, const char *name)
 {
 	liqcell *p=self;
 	//while(p)
@@ -1712,7 +1735,7 @@ liqcell *liqcell_local_lookup(liqcell *self,char *name)
  * @param name The name of the child to find
  * @return liqcell* The found child or NULL
  */
-liqcell*  liqcell_local_lookup_nameclass(liqcell *self,char *name,char *classname)
+liqcell*  liqcell_local_lookup_nameclass(liqcell *self, const char *name, const char *classname)
 {
 	liqcell *p=self;
 	//while(p)
@@ -1730,7 +1753,7 @@ liqcell*  liqcell_local_lookup_nameclass(liqcell *self,char *name,char *classnam
  * @param name The name of the child to find
  * @return liqcell* The found child or NULL
  */
-liqcell*  liqcell_global_lookup(liqcell *self,char *name)
+liqcell*  liqcell_global_lookup(liqcell *self, const char *name)
 {
 	liqcell *p=self;
 	while(p)
@@ -1748,7 +1771,7 @@ liqcell*  liqcell_global_lookup(liqcell *self,char *name)
  * @param name The name of the child to find
  * @return liqcell* The found child or NULL
  */
-liqcell*  liqcell_global_lookup_nameclass(liqcell *self,char *name,char *classname)
+liqcell*  liqcell_global_lookup_nameclass(liqcell *self, const char *name, const char *classname)
 {
 	liqcell *p=self;
 	while(p)
@@ -1787,7 +1810,7 @@ liqcell*  liqcell_global_lookup_nameclass(liqcell *self,char *name,char *classna
  * @param innerh Inner height
  * @return liqcell* The new liqcell
  */
-liqcell*  liqcell_quickcreatewidget(char *name,char *classname,int innerw,int innerh)
+liqcell*  liqcell_quickcreatewidget(const char *name, const char *classname,int innerw,int innerh)
 {
 	liqcell *self = liqcell_new();
 	if(classname && *classname)
@@ -1821,13 +1844,13 @@ liqcell*  liqcell_quickcreatewidget(char *name,char *classname,int innerw,int in
  * @return liqcell* The created liqcell
  * 
  */
-liqcell*  liqcell_quickcreatevis(char *name,char *classname,int x,int y,int w,int h)
+liqcell*  liqcell_quickcreatevis(const char *name, const char *classname,int x,int y,int w,int h)
 {
 	liqcell *self=NULL;	
 	if(classname && *classname)
 	{
 		// gulp!
-		liqcell *dllcache_runconstructor(char *classname);
+		liqcell *dllcache_runconstructor(const char *classname);
 		self = dllcache_runconstructor(classname);
 	}
 	if(!self)
@@ -1853,7 +1876,7 @@ liqcell*  liqcell_quickcreatevis(char *name,char *classname,int x,int y,int w,in
  * @return liqcell* The created liqcell
  * 
  */
-liqcell*  liqcell_quickcreatenameclass(char *name,char *classname)
+liqcell*  liqcell_quickcreatenameclass(const char *name, const char *classname)
 {
 	liqcell *self = liqcell_new();
 	liqcell_setname(self,name);
@@ -1873,7 +1896,7 @@ liqcell*  liqcell_quickcreatenameclass(char *name,char *classname)
  * @return liqcell* The created liqcell
  * 
  */
-liqcell*  liqcell_quickcreatedata(char *name,char *classname,void *data)
+liqcell*  liqcell_quickcreatedata(const char *name, const char *classname,void *data)
 {
 	liqcell *self = liqcell_new();
 	liqcell_setname(self,name);
@@ -1891,7 +1914,7 @@ liqcell*  liqcell_quickcreatedata(char *name,char *classname,void *data)
  * @return liqcell* The created liqcell
  * 
  */
-liqcell*  liqcell_quickcreatecaption(char *name,char *classname,char *caption)
+liqcell*  liqcell_quickcreatecaption(const char *name, const char *classname, const char *caption)
 {
 	liqcell *self = liqcell_new();
 	liqcell_setname(self,name);
@@ -1940,9 +1963,9 @@ int liqcell_iskind(liqcell *self,int cellkind)
  * @param title Title in printinf the tree
  * @param recdep Used in the recursive loop to generate indention
  */
-void liqcell_print(liqcell *self,char *title,int recdep)
+void liqcell_print(liqcell *self, const char *title,int recdep)
 {
-	char *indent = malloc(recdep+1);
+	char *indent = (char *)malloc(recdep+1);
 	if(!indent) return;
 	int i;
 	for(i=0;i<recdep;i++)
@@ -2012,7 +2035,7 @@ int strcmpx (const char * s1, const char * s2)
  * @param handlername The name of the handler to find
  * @return void* The handler
  */
-void*  liqcell_handlerfind(liqcell *self,char *handlername)
+void*  liqcell_handlerfind(liqcell *self, const char *handlername)
 {
 	liqcell *p=self;
 	// only check self
@@ -2051,7 +2074,7 @@ void*  liqcell_handlerfind(liqcell *self,char *handlername)
  * @return liqcell Newly created child liqcell
  * 
  */
-liqcell*  liqcell_handleradd(liqcell *self,char *handlername, void *handler)
+liqcell*  liqcell_handleradd(liqcell *self, const char *handlername, void *handler)
 {
 	//liqapp_log("add %s:%s %i",handlername,"handler",(int)handler);
 
@@ -2068,10 +2091,10 @@ liqcell*  liqcell_handleradd(liqcell *self,char *handlername, void *handler)
  * @return liqcell Newly created child liqcell
  * 
  */
-liqcell*  liqcell_handleradd_withcontext(liqcell *self,char *handlername, void *handler,void *context)
+liqcell*  liqcell_handleradd_withcontext(liqcell *self, const char *handlername, void *handler,void *context)
 {
 	//liqapp_log("add %s:%s %i",handlername,"handler",(int)handler);
-	liqcell *h = liqcell_quickcreatedata(handlername,"handler",handler);
+	liqcell *h = liqcell_quickcreatedata(handlername,"handler", handler);
 	liqcell_settag(h,context);
 	return liqcell_child_insert(self, h );
 }
@@ -2087,7 +2110,7 @@ liqcell*  liqcell_handleradd_withcontext(liqcell *self,char *handlername, void *
  * for success
  * 
  */
-int liqcell_handlerrun(liqcell *self,char *handlername,void *args)
+int liqcell_handlerrun(liqcell *self, const char *handlername,void *args)
 {
 	int (*event_handler)(liqcell *cell,void *args,void *context);
 	liqcell *p=self;
@@ -2112,7 +2135,7 @@ int liqcell_handlerrun(liqcell *self,char *handlername,void *args)
 					// found it!
 					//liqapp_log("ok %s:%s %i",c->name,c->classname,(int)c->data);
 					void *context = liqcell_gettag(c);
-					event_handler = c->data;
+					event_handler = (int (*)(liqcell*, void*, void*))c->data;
 					if(event_handler)
 					{
 						
@@ -2131,7 +2154,8 @@ int liqcell_handlerrun(liqcell *self,char *handlername,void *args)
 							//liqcell_release(self);
 							return res;
 						}
-						return res;		// if the event existed, we run it, no consequence, later, inc ref count and allow recursive multiple event chains
+					//	return res;		// if the event existed, we run it, no consequence, later, inc ref count and allow recursive multiple event chains
+					// 20100129 lcuk removed the return, this should be fun.
 					}
 					//return 0;
 				}
@@ -2169,7 +2193,7 @@ liqcell *liqcell_getbasewidget(liqcell *self)
  * @param classname The string to cechk
  * @param int True or False
  */
-int liqcell_isclass(liqcell *self,char *classname)
+int liqcell_isclass(liqcell *self, const char *classname)
 {
 	// return if this cell is a member of a class
 	return ( (self) && (self->classname) && (strcasecmp(self->classname, classname)==0) );
@@ -2331,15 +2355,15 @@ void liqcell_test()
 
 
 	liqcell *f1 = liqcell_child_insert(root,liqcell_quickcreatenameclass("f1","frame"));
-		liqcell_child_insert(f1,liqcell_new("a","f2"));
-		liqcell_child_insert(f1,liqcell_new("b","f2"));
-		liqcell_child_insert(f1,liqcell_new("c","f2"));
+		liqcell_child_insert(f1,liqcell_new());
+		liqcell_child_insert(f1,liqcell_new());
+		liqcell_child_insert(f1,liqcell_new());
 
 
 	liqcell *f2 = liqcell_child_insert(root,liqcell_quickcreatenameclass("f2","frame"));
-		liqcell_child_insert(f1,liqcell_new("m","f3"));
-		liqcell_child_insert(f1,liqcell_new("n","f3"));
-		liqcell_child_insert(f1,liqcell_new("o","f3"));
+		liqcell_child_insert(f1,liqcell_new());
+		liqcell_child_insert(f1,liqcell_new());
+		liqcell_child_insert(f1,liqcell_new());
 
 
 	liqcell *f3 = liqcell_child_insert(root,liqcell_quickcreatenameclass("f3","button"));
@@ -2356,3 +2380,8 @@ void liqcell_test()
 	// should i dictate a test is required for every class?
 	// seems logical..
 }
+
+#ifdef __cplusplus
+}
+#endif
+
