@@ -26,6 +26,9 @@
 #include "liqcell.h"
 #include "liqcell_prop.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 #define ABS(X) ((X)<0 ? -(X) : (X))
 #define SGN(X) ((X)<0 ? -(1) : (1))
@@ -283,6 +286,14 @@ int liqcell_child_arrange_nooverlap(liqcell *self,liqcell *currentselection)
 
 					//	olw*=1.5;
 					//	olh*=1.5;
+					/*
+						float fracw = ( d->w / (c->w+d->w) ) ;
+						float frach = ( d->h / (c->h+d->h) ) ;
+						c->overlapx+=(float)olw*fracw;
+						c->overlapy+=(float)olh*frach;
+						d->overlapx-=(float)olw*(1-fracw);
+						d->overlapy-=(float)olh*(1-frach);
+					*/
 
 						// we know what the force is going to be and in which direction :)
 						//app_log("c %i, d %i",c->ident,d->ident);
@@ -355,8 +366,15 @@ int liqcell_child_arrange_nooverlap(liqcell *self,liqcell *currentselection)
 					{
 						// are free to make it a bit smaller
 						// need to however find the smallest size
+						
+					if(currentselection)
+					{
+						// can only make it smaller whilst pressing :)
 						if( (c->w-1) > (tilew) ) {c->x++; c->w-=2;  liqcell_setdirty(c,1); }
 						if( (c->h-1) > (tileh) ) {c->y++; c->h-=2;  liqcell_setdirty(c,1); }
+					}
+						
+						
 						if( (c->selected==0) && (c!=currentselection) )
 						{
 							liqcell_forceinboundparent(c);
@@ -398,6 +416,12 @@ int liqcell_child_arrange_makegrid_internal(liqcell *self,int viscolcount,int vi
 	// oo way o.O :)
 	liqcell *c;
 	
+	// invert this for portrait
+	//ROTATEPATCHPOINT sometimes we want more columns than rows..
+	if(canvas.rotation_angle!=0)
+	{
+		if(viscolcount > visrowcount) { int t=viscolcount; viscolcount=visrowcount; visrowcount=t; }
+	}
 	
 	if(viscolcount<=0)
 	{
@@ -507,7 +531,6 @@ retry:
 	int isfinished=1;
 
 	c=liqcell_getlinkchild_visible(self);
-	int remain = answercount;
 	while(c)
 	{
 		
@@ -796,3 +819,8 @@ int liqcell_child_arrange_easycol(liqcell *self)
 	liqcell_setsize(self, rowmaxw, allmaxh);
 	return 0;
 }
+
+#ifdef __cplusplus
+}
+#endif
+
