@@ -44,6 +44,9 @@
 #include "liqcell.h"
 #include "liqcell_dllcache.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 // for now, only use this function
 
@@ -143,7 +146,7 @@ int dllcache_close()
 
 
 
-int dllcache_scan_libraryinternal(char *classname)
+int dllcache_scan_libraryinternal(const char *classname)
 {
 	// we are gonna expand our dllcache
 	
@@ -165,11 +168,13 @@ int dllcache_scan_libraryinternal(char *classname)
 		dllcacheitem->filename   = strdup(classname);
 		dllcacheitem->dll        = dlopen(NULL, RTLD_LAZY | RTLD_GLOBAL );//RTLD_NOW);
 		dllcacheitem->constructor= NULL;
+		
+		return 0;
 }
 
 
 
-int dllcache_scan_dllfile(char *dll_filename)
+int dllcache_scan_dllfile(const char *dll_filename)
 {
 	// we are gonna expand our dllcache
 	
@@ -181,6 +186,10 @@ int dllcache_scan_dllfile(char *dll_filename)
 	
 	dllcacheitem * dllcacheitem=NULL;
 
+
+
+
+
 	
 	if(dll_filename==NULL)
 	{
@@ -203,15 +212,29 @@ int dllcache_scan_dllfile(char *dll_filename)
 		
 		//################################################# prepare the name for usage as a key
 		
-		char *filetitle= liqapp_filename_walkoverpath(dll_filename);
+		const char *filetitle= liqapp_filename_walkoverpath(dll_filename);
 			if(!filetitle){ return liqapp_warnandcontinue(-1,"dllcache_scan_dllfile, no filetitle"); }
-		char *fileext  = liqapp_filename_walktoextension(filetitle);
+		const char *fileext  = liqapp_filename_walktoextension(filetitle);
 			if(!fileext){ return liqapp_warnandcontinue(-1,"dllcache_scan_dllfile, no fileext"); }
 		char filetitlenoext[256];
 		// bug will exist here if i dont watch for it
 		// 20090317_0231 lcuk : todo fix this still
 		snprintf(filetitlenoext,((int)(fileext-filetitle))>255 ? 255 : ((int)(fileext-filetitle)),"%s",filetitle);
 	
+
+
+		// first thing to try is to make sure it doesnt already exist
+		int idx;
+		for(idx=dllcache_used-1;idx>=0;idx--)
+		{
+			dllcacheitem = &dllcache[ idx ];
+			if(strcasecmp(dllcacheitem->key,filetitlenoext)==0 )
+			{
+				liqapp_log("dllcache_scan_dllfile duplicate '%s' with '%s'",dll_filename, liqapp_filename_walkoverpath(dllcacheitem->filename) );
+				// already exists..
+				return -1;
+			}
+		}
 	
 		//################################################# alloc and initialize the cache item :)
 		dllcacheitem = &dllcache[ dllcache_used++ ];
@@ -240,7 +263,7 @@ int dllcache_scan_dllfile(char *dll_filename)
 
 
 
-int dllcache_scan_folder(char *widgetpath)
+int dllcache_scan_folder(const char *widgetpath)
 {
 
 	// scan all files inside the /widgets folder
@@ -292,7 +315,7 @@ int dllcache_scan_folder(char *widgetpath)
 		{
 			// its a regular file
 			
-			char *ext=liqapp_filename_walktoextension(ft);
+			const char *ext=liqapp_filename_walktoextension(ft);
 			if(!ext || !*ext)
 			{
 				// nothing to see here..
@@ -355,6 +378,16 @@ int dllcache_scan()
 		//{ return liqapp_warnandcontinue(-1,"dllcache scan, error while scan 'src/widgets'"); }			
 	}
 	
+	if(dllcache_scan_folder("/usr/share/liqbase")!=0)
+	{
+		// 20090607_193342 lcuk : cheat but might actually work
+		//{ return liqapp_warnandcontinue(-1,"dllcache scan, error while scan 'src/widgets'"); }			
+	}
+	if(dllcache_scan_folder("/usr/share/liqbase/widgets")!=0)
+	{
+		// 20090607_193342 lcuk : cheat but might actually work
+		//{ return liqapp_warnandcontinue(-1,"dllcache scan, error while scan 'src/widgets'"); }			
+	}		
     
     dllcache_scan_libraryinternal("liqkeyboard");
     dllcache_scan_libraryinternal("textbox");
@@ -381,7 +414,7 @@ int dllcache_scan()
 
 
 
-liqcell *dllcache_runconstructorinner(char *classname)
+liqcell *dllcache_runconstructorinner(const char *classname)
 {
 	// must have at least one item in the stack
 	if(runstack_used==0)return NULL;
@@ -389,45 +422,56 @@ liqcell *dllcache_runconstructorinner(char *classname)
 	//liqapp_log("runconstructorinner, looking for: '%s' (stack contains %i items)",classname,runstack_used);
 	
 	char symname[255];
-	snprintf(symname,255,"%s_create",classname);
-
-	// first thing to try is 
 	int idx=0;
-	for(idx=runstack_used-1;idx>=0;idx--)
+	int loop;
+	for(loop=0;loop<3;loop++)
 	{
-		dllcacheitem * dllcacheitem = runstack[ idx ];
+		// 20100101 try 2 variations of default startups
+		// added due to ui apps having _cover and _run as default widgets within instead of the standard
+		if(loop==0)
+			snprintf(symname,255,"%s_create",classname);
+		if(loop==1)
+			snprintf(symname,255,"%s_run_create",classname);
+		if(loop==2)
+			snprintf(symname,255,"%s_cover_create",classname);
 
-
-		//liqapp_log("runconstructorinner, checking stack %i,%s for %s",idx,dllcacheitem->key,classname);
-		
-		
-		liqcell *   	(*constructor)() = NULL;
-		
-		if(strcasecmp(dllcacheitem->key,classname)==0 )
+		// first thing to try is 
+		for(idx=runstack_used-1;idx>=0;idx--)
 		{
-			// to be on the list here we MUST already have the default constructor..
-			constructor = dllcacheitem->constructor;
-		}
-		else
-		{
-			// lets try and use whats available to us :)
-			constructor = dlsym( dllcacheitem->dll, symname);
-		}
-		if(constructor)
-		{
-			//liqapp_log("runconstructorinner, found sym  %i,%s for %s",idx,dllcacheitem->key,classname);
+			dllcacheitem * dllcacheitem = runstack[ idx ];
+	
+	
+			//liqapp_log("runconstructorinner, checking stack %i,%s for %s",idx,dllcacheitem->key,classname);
 			
-			// only interested if we got it, dont care for errors really if we didnt
 			
-			// store the pointer to the library on the stack 
-			runstack[runstack_used++] = dllcacheitem;
-			liqcell *res = constructor();
-			runstack_used--;
-			if(res) return res;
-			
-			liqapp_log("runconstructorinner, error running : '%s.%s_create'",dllcacheitem->key,classname);
-			return NULL;
+			liqcell *   	(*constructor)() = NULL;
 			
+			if(strcasecmp(dllcacheitem->key,classname)==0 )
+			{
+				// to be on the list here we MUST already have the default constructor..
+				constructor = dllcacheitem->constructor;
+			}
+			else
+			{
+				// lets try and use whats available to us :)
+				constructor = (liqcell *(*)())dlsym( dllcacheitem->dll, symname);
+			}
+			if(constructor)
+			{
+				//liqapp_log("runconstructorinner, found sym  %i,%s for %s",idx,dllcacheitem->key,classname);
+				
+				// only interested if we got it, dont care for errors really if we didnt
+				
+				// store the pointer to the library on the stack 
+				runstack[runstack_used++] = dllcacheitem;
+				liqcell *res = constructor();
+				runstack_used--;
+				if(res) return res;
+				
+				liqapp_log("runconstructorinner, error running : '%s.%s_create'",dllcacheitem->key,classname);
+				return NULL;
+				
+			}
 		}
 	}
 	
@@ -453,7 +497,7 @@ liqcell *dllcache_runconstructorinner(char *classname)
  * run a specified constructor and return the result
  */
 
-liqcell *dllcache_runconstructor(char *classname)
+liqcell *dllcache_runconstructor(const char *classname)
 {
 	if(dllcache_size==0)
 	{
@@ -468,7 +512,7 @@ int idx=0;
 
 
 
-	char *dot=strchr(classname,'.');
+	const char *dot=strchr(classname,'.');
 	if(dot)
 	{
 		//
@@ -530,19 +574,35 @@ int idx=0;
 				// 20090615_231546 lcuk : in future, allow context to be used, so tagcloud_create_finger or tagcloud_create_thin etc can be used
 				
 				char symname[255];
-				snprintf(symname,255,"%s_create",dllcacheitem->key);
-				
-				//################################################# get it!
-				dllcacheitem->constructor = dlsym( dllcacheitem->dll, symname);
 
-				//################################################# check for errors
-				const char  *mydll_error;
-				mydll_error = dlerror();
-				if( mydll_error )
+				int loop;
+				for(loop=0;loop<3;loop++)
 				{
-					liqapp_log("dllcache_runconstructor missing constructor: '%s' err '%s'",symname, mydll_error);
-					return NULL;
-				}
+					if(loop==0)
+						snprintf(symname,255,"%s_create",dllcacheitem->key);
+					if(loop==1)
+						snprintf(symname,255,"%s_run_create",dllcacheitem->key);
+					if(loop==2)
+						snprintf(symname,255,"%s_cover_create",dllcacheitem->key);
+								
+								
+		
+						//snprintf(symname,255,"%s_create",dllcacheitem->key);
+						
+						//################################################# get it!
+						dllcacheitem->constructor = (liqcell *(*)())dlsym( dllcacheitem->dll, symname);
+						
+						if(dllcacheitem->constructor) break;
+				}		
+						//################################################# check for errors
+						const char  *mydll_error;
+						mydll_error = dlerror();
+						if( mydll_error )
+						{
+							liqapp_log("dllcache_runconstructor missing constructor: '%s' err '%s'",symname, mydll_error);
+							return NULL;
+						}
+
 			}
 			
 			//################################################# run the constructor
@@ -604,3 +664,8 @@ int           dllcache_getused()
 	}	
 	return dllcache_used;	
 }
+
+#ifdef __cplusplus
+}
+#endif
+
