@@ -1,6 +1,5 @@
 
 
-#define _GNU_SOURCE
 #include <string.h>
 #include <stdlib.h>
 
@@ -13,6 +12,7 @@
 #include <ctype.h>
 #include <pthread.h>
 #include <sched.h>
+#include <math.h>
 
 
 
@@ -27,6 +27,10 @@
 #include "liqcell_prop.h"
 #include "liqcell_easyrun.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 //liqfont *easyinfofont;
 
 // for the vgraph
@@ -38,7 +42,7 @@
 // ie a reference to the current cell
 
 int liqcell_showdebugboxes=0;
-
+int liqcell_showfps=0;
 
 
 
@@ -120,7 +124,6 @@ void *mainthread(void* mainthread_data)
 	//liqapp_sleep(100 + (rand() % 4000));
 	//liqapp_sleep(100 + (rand() % 2000));
 	liqcell *self = (liqcell *)mainthread_data;
-	liqcell *par=liqcell_getlinkparent(self);
 do
 {
 //	liqapp_sleep(10 + (rand() % 100));
@@ -138,9 +141,6 @@ while( (mainthread_inprogress>1) ); //   || (par && (par->kineticx || par->kinet
 
 	// we are here to load the image named on self and then finish
 
-
-	liqimage *img = liqcell_getimage(self);
-
 	//if(img == easypaint_isloading_image)
     
 	{
@@ -354,7 +354,7 @@ int liqcell_threadloadimage(liqcell *self)
 						liqapp_log("liqcell_easypaint: thread create fail %s :: %i",liqcell_getcaption(self),tres);
 						//liqcliprect_release(cr);
 						liqcell_release(self);
-						return;
+						return -1;
 					}
 				}
 	return 0;
@@ -388,7 +388,7 @@ static float calcaspect(int captionw,int captionh,int availw,int availh)
 }
 
 
-unsigned int decodecolor(char *source,unsigned char *ry,unsigned char *ru,unsigned char *rv,unsigned char *ra,unsigned char *rc)
+unsigned int decodecolor(const char *source,unsigned char *ry,unsigned char *ru,unsigned char *rv,unsigned char *ra,unsigned char *rc)
 {
 	char inbuf[1024];
 	snprintf(inbuf,1024,source);
@@ -587,14 +587,127 @@ static int liqcell_kineticboiloff(liqcell *self)
 //
 }
 
+void liqcell_check_for_driedup(liqcell *self)
+{
+	if( !self->paintlastframenumber ) return;	// never painted
+	
+	if(self->paintlastframenumber+5 > canvas.framecount) return; // painted recently
+	
+	// its been painted a while ago, and its now offscreen
+	// tell the cell its going offscreen
+	liqapp_log("dried up '%s'",self->name);
+	self->paintlastframenumber=0;
+	liqcell_handlerrun(self,"driedup",NULL);
+	
+}
+
+void liqcell_easypaint_int(liqcell *self,liqcliprect *crorig,    int x,int y,    int w,int h);
+void liqcell_easypaintkkk(liqcell *self,liqcliprect *crorig,    int x,int y,    int w,int h)
+{
+	// this needs more work, its not going to work as is
+	if(w<1 || h<1)
+	{
+		//liqapp_log("size0 bail!");
+		liqcell_check_for_driedup(self);
+		return;
+	}
+	if(self->w==0 || self->h==0)
+	{
+		//liqapp_log("box0 bail!");
+		liqcell_check_for_driedup(self);
+		return;
+	}
+	if(!self->visible)
+	{
+		//liqapp_log("vis bail!");
+		liqcell_check_for_driedup(self);
+		return;
+	}
+	// shit this is at wrong location, theres many reasons to bailout which this does not handle
+	
+
+	liqcliprect *crvis= liqcliprect_new();
+	liqcliprect_copy(crvis,crorig);
+	liqcliprect_shrink(crvis,x,y,x+w,y+h);
+
+//unsigned long 	tz0=liqapp_GetTicks();
+
+//__tz_one("clipgot");
+	//liqapp_log("easypaint 1");
+
+	if(!liqcliprect_isvalid(crvis))
+	{
+		//liqapp_log("cr bail!");
+		liqcell_check_for_driedup(self);
+		liqcliprect_release(crvis);
+		return;
+	}
+
+	// allow gravity to dictate the angle
+	// or for this demo flip it upsidedown
+	int angle=0;
+	if(w<=400 && h<=240)angle=90;
+	if(angle==0)
+	{
+		liqcell_easypaint_int(self,crorig,x,y,w,h);
+	}
+	else
+	if(angle==90)
+	{
+		// make a bitmap(h*w), draw on it, rotblit it into space
+		//liqcell_easypaint_int(self,crorig,x,y,w,h);
+
+
+		liqapp_log("...creating image %i,%i",h,w);	
+		liqimage *img = liqimage_newatsize(h,w,0);
+		
+		liqapp_log("...creating cliprect");
+		liqcliprect *cr = liqcliprect_newfromimage(img);
+		
+		liqapp_log("rendering image.." );
+		liqcliprect_hold(cr);
+		liqcell_easypaint_int(self,cr,0,0,h,w);
+		
+		
+		liqapp_log("rot blitting image.." );
+		// todo.
+		
+		liqcliprect_drawimagecolor(crorig, img, x,y, w,h, 0);
+		
+		liqapp_log("...releasing cr");
+		liqcliprect_release(cr);
+		
+		liqapp_log("...releasing image");
+		liqimage_release(img);		
+		
+		liqapp_log("...fin");
+
+	}
+	
+	liqcliprect_release(crvis);
+}
+
 
 
 
 void liqcell_easypaint(liqcell *self,liqcliprect *crorig,    int x,int y,    int w,int h)
 {
+	liqcell_easypaint_int(self,crorig,x,y,w,h);
+}
 
 
-	//liqapp_log("#################################### liqcell easypaint (%i,%i) :: %s   xy(%i,%i)-wh(%i,%i)  cr==can.cr ? %i",self->w,self->h,self->name,x,y,w,h,crorig==liqcanvas_getcliprect());
+static int ishttp(char *filename)
+{
+	if(tolower(filename[0])=='h' && tolower(filename[1])=='t' && tolower(filename[2])=='t' && tolower(filename[3])=='p' && tolower(filename[4])==':')
+		return 1;
+	return 0;
+}
+
+void liqcell_easypaint_int(liqcell *self,liqcliprect *crorig,    int x,int y,    int w,int h)
+{
+
+
+	//liqapp_log("#################################### liqcell easypaint (%i,%i) :: %s   xy(%i,%i)-wh(%i,%i)  cap('%d')",self->w,self->h,self->name,x,y,w,h,liqcell_getcaption(self));
 	
 	
 
@@ -617,22 +730,27 @@ __tz_one("start");
 
 
 //char cy,cu,cv;
+/*
+
 	if(w<1 || h<1)
 	{
 		//liqapp_log("size0 bail!");
+		liqcell_check_for_driedup(self);
 		return;
 	}
 	if(self->w==0 || self->h==0)
 	{
 		//liqapp_log("box0 bail!");
+		liqcell_check_for_driedup(self);
 		return;
 	}
 	if(!self->visible)
 	{
 		//liqapp_log("vis bail!");
+		liqcell_check_for_driedup(self);
 		return;
 	}
-	
+*/	
 	//liqapp_log("easypaint 0");
 	
 __tz_one("sizeok");
@@ -649,11 +767,15 @@ __tz_one("clipgot");
 	if(!liqcliprect_isvalid(cr))
 	{
 		//liqapp_log("cr bail!");
+		liqcell_check_for_driedup(self);
 		liqcliprect_release(cr);
 		return;
 	}
 __tz_one("clipok");
 
+	// onscreen, so save the frame number away
+	self->paintlastframenumber = canvas.framecount;
+
 	if(self->classname)
 	{
 		if( strcmp(self->classname,"overlay") ==0 )
@@ -753,7 +875,7 @@ __tz_one("paintdone");
 
 
 
-	char *t=NULL;
+	const char *t=NULL;
 	unsigned char bcy=255;
 	unsigned char bcu=128;
 	unsigned char bcv=128;
@@ -777,7 +899,8 @@ __tz_one("paintdone");
                 {
                     if(!easypaint_backgrain_image)
                     {
-                         easypaint_backgrain_image=liqimage_newfromfile("/usr/share/liqbase/libliqbase/media/backgrain.png",0,0,0);
+						// try allowing with alpha..
+                         easypaint_backgrain_image=liqimage_newfromfile("/usr/share/liqbase/libliqbase/media/backgrain.png",0,0,1);
                     }
                     if(easypaint_backgrain_image)
                     {
@@ -805,14 +928,6 @@ __tz_one("paintdone");
 __tz_one("backdone");
 		//liqcliprect_drawimagecolor(cr,camimage,x,y,w,h,0);
 
-	int ishttp(char *filename)
-	{
-		if(tolower(filename[0])=='h' && tolower(filename[1])=='t' && tolower(filename[2])=='t' && tolower(filename[3])=='p' && tolower(filename[4])==':')
-			return 1;
-		return 0;
-	}
-
-
 	if(!self->image)
 	{
 		//liqapp_log("paint_image trying to load for %s",self->name);
@@ -905,14 +1020,12 @@ __tz_one("imageprep");
 
 
 				//################################################## lj variaton
-				unsigned long timer1 = liqapp_GetTicks();
-				
 				float secs=0;// = ((float)timer1 / 1000.0);
 				
 				
 				
 				
-				int rs=sscanf(fstr,"%f",&secs);
+				sscanf(fstr,"%f",&secs);
 				
 				
 				
@@ -922,7 +1035,7 @@ __tz_one("imageprep");
 				
 
 				
-				unsigned int rndofname = *(unsigned int *)&self->name;
+				unsigned int rndofname = *(unsigned int *)self->name;
 				
 				secs+=rndofname;
 
@@ -1826,3 +1939,8 @@ int i=0;
 #endif
 
 }
+
+#ifdef __cplusplus
+}
+#endif
+
