@@ -1,4 +1,6 @@
-
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 //###############################################################################
 //############################################################################### Group
@@ -52,3 +54,7 @@ liqcell *mkgroup(char *key,liqcell *first,...)
 	return self;
 }
 
+#ifdef __cplusplus
+}
+#endif
+
