@@ -6,6 +6,7 @@
 #include <memory.h>
 
 
+
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/Xatom.h>
@@ -17,13 +18,17 @@
 #include <setjmp.h>
 #include <jpeglib.h>
 
-
+#include <pthread.h>
+#include <sched.h>
 
 #include "liqapp.h"
 #include "liqimage.h"
 #include "liqcanvas.h"
 #include "liqcliprect.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 
 void liqimage_mark_barcode(liqimage *self);
@@ -42,6 +47,7 @@ static struct
 static int  cachemax=4096-1;
 static int  cacheused=0;
 
+static pthread_mutex_t cachestack_lock = PTHREAD_MUTEX_INITIALIZER;
 
 static int liqimage_cache_clean_unused(int maxremove)
 {
@@ -98,10 +104,17 @@ static int liqimage_cache_clean_unused(int maxremove)
 //####################################################################
 //####################################################################
 
+int liqimage_getwidth(liqimage *self)
+{
+	return self->width;
+}
+int liqimage_getheight(liqimage *self)
+{
+	return self->height;
+}
 
 
-
-liqimage *liqimage_cache_lookuponly(char *filename,int maxw,int maxh,int allowalpha)
+liqimage *liqimage_cache_lookuponly(const char *filename,int maxw,int maxh,int allowalpha)
 {
 	//
 	liqimage *self=NULL;
@@ -140,7 +153,7 @@ liqimage *liqimage_cache_lookuponly(char *filename,int maxw,int maxh,int allowal
 
 
 
-liqimage *liqimage_cache_getfile(char *filename,int maxw,int maxh,int allowalpha)
+liqimage *liqimage_cache_getfile(const char *filename,int maxw,int maxh,int allowalpha)
 {
 	//
 	liqimage *self=NULL;
@@ -162,6 +175,7 @@ liqimage *liqimage_cache_getfile(char *filename,int maxw,int maxh,int allowalpha
 	//for(f=0;f<cacheused;f++)
 	for(f=cacheused-1;f>=0;f--)
 	{
+		// pagefault here (at least according to gdb), its most likely related to the bug noticed below, will investigate more
 		if(strcmp(cachestack[f].key,cachekey)==0)
 		{
 			// no differences..
@@ -201,11 +215,20 @@ liqimage *liqimage_cache_getfile(char *filename,int maxw,int maxh,int allowalpha
 	//self->usagecount=1;
 
 	//liqapp_log( "TTF cache inserting %s", cachekey );
+	
+	
+	// todo:  fix the bug here when threaded loading occuring
+	// the RMW cycle is badly mixed up when creating a cache item and adding its data
+	// multithreaded handling of this is wrong since both may grab the same input
+	pthread_mutex_lock(&cachestack_lock);
 
 	f=cacheused;
 	cachestack[f].key  = strdup(cachekey);
 	cachestack[f].data = self;
 	cacheused++;
+	
+	pthread_mutex_unlock(&cachestack_lock);
+
 	////liqapp_log( "TTF cache completed %s", cachekey );
 	return self;
 }
@@ -302,10 +325,9 @@ liqimage *  liqimage_newatsize(          int w,int h,int allowalpha)
 }
 
 
-liqimage *liqimage_newfromfile(char *filename,int maxw,int maxh,int allowalpha)
+liqimage *liqimage_newfromfile(const char *filename,int maxw,int maxh,int allowalpha)
 {
-	
-	char *ext = liqapp_filename_walktoextension(filename);
+	const char *ext = liqapp_filename_walktoextension(filename);
 	if(!ext || !*ext)
 	{
 		liqapp_log("liqimage_newfromfile invalid filename '%s'",filename);
@@ -423,7 +445,7 @@ liqimage *liqimage_newfromfile(char *filename,int maxw,int maxh,int allowalpha)
 
 
 
-liqimage *liqimage_newfromfilejpeg(char *filename)
+liqimage *liqimage_newfromfilejpeg(const char *filename)
 {
 
 		//app.infologgingenabled=0;
@@ -442,7 +464,7 @@ liqimage *liqimage_newfromfilejpeg(char *filename)
 }
 
 
-liqimage *liqimage_newfromfilepng(char *filename,int allowalpha)
+liqimage *liqimage_newfromfilepng(const char *filename,int allowalpha)
 {
 
 		//app.infologgingenabled=0;
@@ -556,7 +578,7 @@ int num_planes;
 	else
 		num_planes=3;
 
-int *picoffsets=malloc(sizeof(int)*num_planes);
+int *picoffsets=(int *)malloc(sizeof(int)*num_planes);
 	if(!picoffsets)
 	{
 		liqapp_log("image: page defined could not alloc offsets");
@@ -571,7 +593,7 @@ int *picoffsets=malloc(sizeof(int)*num_planes);
 	if(hasalpha)
 		picoffsets[3] = picoffsets[1] + ((w/2) * (h/2)) * 2;
 	
-int *picpitches=malloc(sizeof(int)*num_planes);
+int *picpitches=(int *)malloc(sizeof(int)*num_planes);
 
 	if(!picpitches)
 	{
@@ -591,7 +613,7 @@ int *picpitches=malloc(sizeof(int)*num_planes);
 	self->num_planes = num_planes;
 	self->offsets    = picoffsets;
 	self->pitches    = picpitches;
-	self->data       = malloc(self->data_size);
+	self->data       = (unsigned char *)malloc(self->data_size);
 	if(!self->data)
 	{
 		liqapp_log("image: page defined could not alloc plane data");
@@ -612,7 +634,7 @@ int *picpitches=malloc(sizeof(int)*num_planes);
 
 void liqimage_pagedefinefromXVImage(liqimage *self,void *XvImagePtr,int dpix,int dpiy)
 {
-XvImage *XvImage=XvImagePtr;
+    XvImage *img = (XvImage *)XvImagePtr;
 	//if(picbuff_ready) return;
 	
 	liqapp_log("liqimage pagedefinefromxv");
@@ -621,23 +643,23 @@ XvImage *XvImage=XvImagePtr;
 	
 	liqapp_log("liqimage pagedefinefromxv2");
 	
-int w=XvImage->width;
-int h=XvImage->height;
-int num_planes=XvImage->num_planes;
+int w=img->width;
+int h=img->height;
+int num_planes=img->num_planes;
 	if(num_planes>3)num_planes=3;
 	liqapp_log("liqimage pagedefinefromxv3 planes=%i  hmm=%i",num_planes,sizeof(int)*num_planes);
 
-int *picoffsets=malloc(sizeof(int)*num_planes);
+int *picoffsets=(int *)malloc(sizeof(int)*num_planes);
 	liqapp_log("liqimage pagedefinefromxv3.5");
-int *picpitches=malloc(sizeof(int)*num_planes);
+int *picpitches=(int *)malloc(sizeof(int)*num_planes);
 int i;
 
 	liqapp_log("liqimage pagedefinefromxv4");
 
 	for(i=0;i<num_planes;i++)
 	{	
-		picoffsets[i] = XvImage->offsets[i];
-		picpitches[i] = XvImage->pitches[i];
+		picoffsets[i] = img->offsets[i];
+		picpitches[i] = img->pitches[i];
 	}
 
 
@@ -646,11 +668,11 @@ int i;
 
 	self->width      = w;
 	self->height     = h;
-	self->data_size  = XvImage->data_size;
+	self->data_size  = img->data_size;
 	self->num_planes = num_planes;
 	self->offsets    = picoffsets;
 	self->pitches    = picpitches;
-	self->data       = (unsigned char *)XvImage->data;
+	self->data       = (unsigned char *)img->data;
 	self->XVImageSource = XvImagePtr;
 	self->dpix = dpix;
 	self->dpiy = dpiy;
@@ -689,7 +711,7 @@ void liqimage_jpeg_error_exit(j_common_ptr cinfo)
 
 
 
-int liqimage_pageloadjpeg(liqimage *self,char * filename,int maxw,int maxh)
+int liqimage_pageloadjpeg(liqimage *self, const char * filename,int maxw,int maxh)
 {
 	// why did this take so much code for such a straight forward job?
 	// will I have to go through similar for other image formats?
@@ -802,7 +824,7 @@ int 							row_stride;
 	row_stride = cinfo.output_width * cinfo.output_components;
 	int x=0;
 	int y=0;
-	buffer = malloc( row_stride * sizeof(char) );		// allocate a line block
+	buffer = (unsigned char *)malloc( row_stride * sizeof(char) );		// allocate a line block
 	int i;
 	for (i = 0; i < cinfo.output_components; i++)
 	{
@@ -891,7 +913,7 @@ int 							row_stride;
 // http://trac.enlightenment.org/e/browser/trunk/PROTO/enesim/examples/image.c?rev=35582
 
 //static image_info_t *decompress_png(const char *filename)
-int liqimage_pageloadpng(liqimage *self,char * filename,int maxw,int maxh,int allowalpha)
+int liqimage_pageloadpng(liqimage *self, const char * filename,int maxw,int maxh,int allowalpha)
 {
 	return liqimage_pageloadpng_memstream(self,filename,NULL,0,maxw,maxh,allowalpha);
 }
@@ -933,7 +955,7 @@ static void png_read_data(png_structp png_ptr, png_bytep area, png_size_t size)
 }
 
 
-int liqimage_pageloadpng_memstream(liqimage *self,char * filename,char *srcdata, int srcsize,int maxw,int maxh,int allowalpha)
+int liqimage_pageloadpng_memstream(liqimage *self, const char * filename,char *srcdata, int srcsize,int maxw,int maxh,int allowalpha)
 {
 	// 20090715_224851 lcuk : srcdata and srcsize are memory array versions
 	// 20090715_224901 lcuk : pass NULL and 0 as well as a valid filename to use standard procedure
@@ -1183,7 +1205,7 @@ int liqimage_pageloadpng_memstream(liqimage *self,char * filename,char *srcdata,
 	liqapp_log("png: rowbytes=%i",rowbytes);
 	
 	
-	unsigned char * image_data = malloc(rowbytes * image.ht);
+	unsigned char * image_data = (unsigned char *)malloc(rowbytes * image.ht);
 		if(!image_data)
 		{
 			liqapp_log("png.image_data malloc fail");
@@ -1192,7 +1214,7 @@ int liqimage_pageloadpng_memstream(liqimage *self,char * filename,char *srcdata,
 			return -6;
 		}
 	
-	png_bytepp row_pointers = malloc(image.ht * sizeof(png_bytep));
+	png_bytepp row_pointers = (png_bytepp)malloc(image.ht * sizeof(png_bytep));
 		if(!row_pointers)
 		{
 			liqapp_log("png.row_pointers malloc fail");
@@ -1372,64 +1394,9 @@ int liqimage_pageloadpng_memstream(liqimage *self,char * filename,char *srcdata,
 
 
 
+inline static unsigned char clip(int indat){ return (indat<0) ? 0 : ( (indat>255) ? 255 : indat) ;  }
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-int liqimage_pagesavepng(liqimage *self,char * filename)
+int liqimage_pagesavepng(liqimage *self, const char * filename)
 {
 	//
 	liqapp_log("png save called %i,%i: to '%s'",self->width,self->height,filename);
@@ -1496,7 +1463,7 @@ int liqimage_pagesavepng(liqimage *self,char * filename)
     png_byte **rowoffsets;
 	int x,y;
 	liqapp_log("png allocating rgb buffer");
-	char *rgbabuffer = malloc(png_bytesperpixel * self->width * self->height);		// alloc rgb buffer RGBA
+	char *rgbabuffer = (char *)malloc(png_bytesperpixel * self->width * self->height);		// alloc rgb buffer RGBA
     if (!rgbabuffer)
 	{
 		fclose(outf);
@@ -1517,7 +1484,6 @@ int liqimage_pagesavepng(liqimage *self,char * filename)
 			// convert YUV -> RGB
 			//http://msdn.microsoft.com/en-us/library/ms893078.aspx
 			// yes, microsoft are useful :)
-			inline unsigned char clip(int indat){ return (indat<0) ? 0 : ( (indat>255) ? 255 : indat) ;  }
 			int           ic = (((int)iy)) - 16;
 			int           id = (((int)iu)) - 128;
 			int           ie = (((int)iv)) - 128;
@@ -1541,7 +1507,7 @@ int liqimage_pagesavepng(liqimage *self,char * filename)
 	// ####################################### now get on with the hard work
 	liqapp_log("png allocating row buffer");
 
-    rowoffsets = malloc(sizeof(png_byte*) * self->height);
+    rowoffsets = (png_bytepp)malloc(sizeof(png_byte*) * self->height);
     if (!rowoffsets)
 	{
 		fclose(outf);
@@ -1722,8 +1688,7 @@ int liqimage_pagesavepng(liqimage *self,char * filename)
   //442         }
 
 	
-	
-	
-	
-
+#ifdef __cplusplus
+}
+#endif
 
