@@ -36,6 +36,10 @@
 #include "liqcanvas.h"
 #include "liqsketch.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 //#include "liqdoc.h"
 
 //#########################################################################
@@ -43,8 +47,16 @@
 //#########################################################################
 //#########################################################################
 //#########################################################################
+//#include <pthread.h>
+//#include <sched.h>
+	// crashing liqflow via osc when removing a node, this is bad
+	// its a threading issue tho
+	// one process is recurings each stroke, the other is using it
+	//
 
-
+//static pthread_mutex_t sketch_op_lock = PTHREAD_MUTEX_INITIALIZER;
+	//pthread_mutex_lock(&sketch_op_lock);
+	//pthread_mutex_unlock(&sketch_op_lock);
 
 liqpoint *liqpoint_new()
 {
@@ -142,8 +154,6 @@ void liqpointrange_extendrubberband(liqpointrange *self,liqpoint *p)
 	if(self->zf < p->z)self->zf = p->z;
 	if(self->zb > p->z)self->zb = p->z;
 }
-
-
 int liqpointrange_isconnected(liqpointrange *self,liqpointrange *b)
 {
 	
@@ -156,6 +166,27 @@ int liqpointrange_isconnected(liqpointrange *self,liqpointrange *b)
 
 
 
+void          liqpointrange_start_xyz(liqpointrange *self,int px,int py,int pz)
+{
+	self->xl = px;
+	self->xr = px;
+	self->yt = py;
+	self->yb = py;
+	self->zf = pz;
+	self->zb = pz;
+}
+void          liqpointrange_extendrubberband_xyz(liqpointrange *self,int px,int py,int pz)
+{
+	if(self->xl > px)self->xl = px;
+	if(self->xr < px)self->xr = px;
+	if(self->yt > py)self->yt = py;
+	if(self->yb < py)self->yb = py;
+	if(self->zf < pz)self->zf = pz;
+	if(self->zb > pz)self->zb = pz;
+}
+
+
+
 
 //#########################################################################
 //#########################################################################
@@ -698,12 +729,14 @@ void liqsketch_titlechange(liqsketch *self,char *title)
 
 // '''''''''''''''''''''''''''''''''''''''''''''''''''''''''
 
-
-
 void          liqsketch_strokeremove(liqsketch *self,liqstroke *s)
 {
 	//
 	if(!s)return;
+	
+	//pthread_mutex_lock(&sketch_op_lock);
+	//
+	
 	//if(! (s->linkpage==self) ) return;
 	liqstroke *l=s->linkprev;
 	liqstroke *r=s->linknext;
@@ -729,7 +762,11 @@ void          liqsketch_strokeremove(liqsketch *self,liqstroke *s)
 	s->linknext=NULL;
 	s->linkpage=NULL;
 	
-	liqstroke_free(s);
+	//pthread_mutex_unlock(&sketch_op_lock);
+	
+	//liqstroke_free(s);
+	liqstroke_release(s);
+	
 	
 	self->strokecount--;
 	
@@ -1240,3 +1277,8 @@ liqimage *liqsketch_getbackgroundimage(liqsketch *self)
 {
 	return self->backgroundimage;
 }
+
+#ifdef __cplusplus
+}
+#endif
+
