@@ -206,19 +206,24 @@ int liqx11info_init(liqx11info *myx11info, int pixelwidth,int pixelheight,int fu
 	
 	
 
+int       xvoverlaycolorkey=-1;
+int       xvautopaintcolorkey=-1;
 
+if( liqapp_hardware_product_ispowerful_get() )
+{
+	
 
 XvPortID  xvport_num = x11_get_first_xvport(myx11info->mydisplay);
 
 #ifdef USE_MAEMO
-int       xvoverlaycolorkey=-1;
+
 	// This code barfs on the desktop for me (Robin), nvidia drivers.. so make it Maemo-only.
         Atom xv_colorkey = XInternAtom(myx11info->mydisplay, "XV_COLORKEY", 0);
         XvGetPortAttribute(myx11info->mydisplay, xvport_num, xv_colorkey, &xvoverlaycolorkey);
 		
 		
 		
-int       xvautopaintcolorkey=-1;
+
 
         Atom xv_autopaintcolorkey = XInternAtom(myx11info->mydisplay, "XV_AUTOPAINT_COLORKEY", 0);
         XvGetPortAttribute(myx11info->mydisplay, xvport_num, xv_autopaintcolorkey, &xvautopaintcolorkey);
@@ -234,6 +239,8 @@ int       xvautopaintcolorkey=-1;
 	
 #endif
 
+}
+
 	//################################################# 
 	
 	
@@ -245,14 +252,17 @@ int       xvautopaintcolorkey=-1;
 	
 		mybackground  = BlackPixel(myx11info->mydisplay, myx11info->myscreen);
 		myforeground  = WhitePixel(myx11info->mydisplay, myx11info->myscreen);
-		
+
+
+if( liqapp_hardware_product_ispowerful_get() )
+{		
 #ifdef USE_MAEMO
 		// See above. We don't use xvoverlaycolorkey off Maemo.
 		liqapp_log("colors Back=%d fore=%d key=%d",mybackground,myforeground,xvoverlaycolorkey);
 		
 		mybackground = xvoverlaycolorkey;
 #endif
-
+}
 
 	
 		myhint.x      = 0;
