@@ -23,10 +23,14 @@
 #include <X11/keysymdef.h>
 
 #include "liqbase.h"
+#include "liqapp_prefs.h"
 
 #include "liqx11overlay.h"
 
 
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 //#############################################################
 extern int 			XShmQueryExtension(Display*);
@@ -38,9 +42,7 @@ extern XvImage  *	XvShmCreateImage(Display*, XvPortID, int, char*, int, int, XSh
 //#############################################################
 
 
-
-
-int liqx11overlay_init(liqx11overlay *self, Display *dpy, int screen, Window window, GC gc)
+int liqx11overlay_init(liqx11overlay *self, Display *dpy, int screen, Window window, GC gc, int attrswidth,int attrsheight)
 {
 	liqapp_log("x11overlay init begin");
 	
@@ -64,20 +66,20 @@ int liqx11overlay_init(liqx11overlay *self, Display *dpy, int screen, Window win
 	//################################################# find out our dimensions
 
 
-	XWindowAttributes attrs;
-	XGetWindowAttributes(
-								 self->dpy,
-								 self->window,
-								 &attrs );
+	//XWindowAttributes attrs;
+	//XGetWindowAttributes(
+	//							 self->dpy,
+	//							 self->window,
+	//							 &attrs );
 
-	self->yuv_width  = attrs.width;
-	self->yuv_height = attrs.height;
+	self->yuv_width  = attrswidth;
+	self->yuv_height = attrsheight;
 
 // Sat Aug 22 00:52:46 2009 lcuk : lowres flag added, if set half the resolution of the overlay
 if( liqapp_pref_checkexists("lowres") )
 {
-	self->yuv_width  = attrs.width/2;
-	self->yuv_height = attrs.height/2;
+	self->yuv_width  = attrswidth/2;
+	self->yuv_height = attrsheight/2;
 }
 
 	liqapp_log("x11overlay dims wh(%i,%i)",self->yuv_width,self->yuv_height);
@@ -117,6 +119,7 @@ if(self->yuv_width==480 && self->yuv_height==800)
 		{ return liqapp_errorandfail(-1,"canvas No XV Port on default adapter"); }	
 	}
 
+
 	//################################################# setup shared memory access
 	
 	liqapp_log("x11overlay XShm init begin");
@@ -126,6 +129,11 @@ if(self->yuv_width==480 && self->yuv_height==800)
 		{ return liqapp_errorandfail(-1,"canvas XShmQueryExtension failed"); }
 	}
 
+	// for green bug
+	// look into XvSetPortAttribute
+	// http://www.xfree86.org/current/XvSetPortAttribute.3.html
+	// http://lists.helixcommunity.org/pipermail/video-cvs/2009-September/001467.html
+	
 
 	//YUV12 and IV420 are same but U&V are swapped
 	self->yuv_image = XvShmCreateImage(self->dpy, self->xv_port, GUID_YUV12_PLANAR, 0, self->yuv_width, self->yuv_height, &self->yuv_shminfo);
@@ -133,21 +141,48 @@ if(self->yuv_width==480 && self->yuv_height==800)
 
 
 	self->yuv_shminfo.shmid = shmget(IPC_PRIVATE, self->yuv_image->data_size, IPC_CREAT | 0777);
-	self->yuv_shminfo.shmaddr = self->yuv_image->data = shmat(self->yuv_shminfo.shmid, 0, 0);
+	self->yuv_shminfo.shmaddr = self->yuv_image->data = (char *)shmat(self->yuv_shminfo.shmid, 0, 0);
 	self->yuv_shminfo.readOnly = False;
 
-
-
+	
 	//################################################# setup the surface and liqcliprect
-	liqapp_log("x11overlay creating canvas.surface");
-	canvas.surface=liqimage_new();
-	if (!canvas.surface) 
+	// rotpatch : replace the initial surface definition with the one for the unrotated surface
+	liqapp_log("x11overlay creating canvas.rotation_native_surface wh %d,%d",self->yuv_width, self->yuv_height);
+	canvas.rotation_native_surface=liqimage_new();
+	if (!canvas.rotation_native_surface) 
 	{
 		{ liqapp_errorandfail(-1,"canvas liqimage_create failed"); }
 		return -1;
 	}
-	liqimage_pagedefinefromXVImage(canvas.surface,self->yuv_image,canvas.dpix,canvas.dpiy);
+	liqimage_pagedefinefromXVImage(canvas.rotation_native_surface , self->yuv_image,canvas.dpix,canvas.dpiy);
 
+	
+	// rotpatch : assign the surface to the unrotated surface, OR construct a duplicate
+	canvas.surface = canvas.rotation_native_surface;
+
+	canvas.rotation_angle=0;
+	
+	if( atoi(liqapp_pref_getvalue("forcerotation"))==1)
+//	if(0)
+	{
+		liqapp_log("x11overlay forcing rotation FROM wh %d,%d",self->yuv_height, self->yuv_width);
+		// rotpatch : force everything to be rotated..
+		canvas.rotation_angle=90;
+		self->yuv_width  = attrsheight;
+		self->yuv_height = attrswidth;
+		attrswidth=self->yuv_width;
+		attrsheight=self->yuv_height;
+		
+		liqapp_log("x11overlay forcing rotation  TO  wh %d,%d",self->yuv_height, self->yuv_width);
+		
+		canvas.surface = liqimage_newatsize(self->yuv_width,self->yuv_height,0);
+		if (!canvas.surface) 
+		{
+			{ liqapp_errorandfail(-1,"canvas liqimage_create failed to create rotation backbuffer"); }
+			return -1;
+		}	
+	}
+	
 
 
 
@@ -186,9 +221,30 @@ int liqx11overlay_close(liqx11overlay *self)
 	if(canvas.cr){ liqcliprect_release(canvas.cr);   canvas.cr=NULL; }
 
 
+	if(canvas.surface == canvas.rotation_native_surface)
+	{
+		liqapp_log("x11overlay surface == rotation_native_surface");
+		canvas.surface = NULL;
+	}
+	else
+	{
+		// HACK - restore the original w/h hope this works..
+		canvas.pixelwidth  = self->yuv_height;
+		canvas.pixelheight = self->yuv_width;		
+	}
 
-	if(canvas.surface){ liqimage_release(canvas.surface); canvas.surface=NULL; }
-	
+	if(canvas.rotation_native_surface)
+	{
+		liqapp_log("x11overlay freeing rotation_native_surface");
+		liqimage_release(canvas.rotation_native_surface);
+		canvas.rotation_native_surface=NULL;
+	}
+	if(canvas.surface)
+	{
+		liqapp_log("x11overlay freeing surface");
+		liqimage_release(canvas.surface);
+		canvas.surface=NULL;
+	}	
 	
 	
 
@@ -217,12 +273,16 @@ int liqx11overlay_close(liqx11overlay *self)
 
 
 
+
 int liqx11overlay_show(liqx11overlay *self)
 {
     //return 0;    
-	liqapp_log("x11overlay show begin");
 	
 	if(self->yuv_shminfo_attached) return 0;
+
+	liqapp_log("x11overlay show begin");
+
+	//liqapp_sleep(500);
 	
 	liqapp_log("x11overlay showing");
 	
@@ -231,6 +291,8 @@ int liqx11overlay_show(liqx11overlay *self)
 		{ return liqapp_errorandfail(-1,"canvas XShmAttach failed"); }
 	}
 	
+	//liqapp_sleep(500);
+	
 	liqapp_log("x11overlay shown");
 	self->yuv_shminfo_attached=1;
 	return 0;
@@ -249,8 +311,12 @@ int liqx11overlay_hide(liqx11overlay *self)
 	if(!self->yuv_shminfo_attached) return 0;
 
 	liqapp_log("x11overlay hiding");
+	
+	XFlush (self->dpy);
 
 	XShmDetach(self->dpy,&self->yuv_shminfo);
+	
+	XFlush (self->dpy);
 
 	self->yuv_shminfo_attached=0;
 
@@ -271,8 +337,8 @@ int liqx11overlay_refreshdisplay(liqx11overlay *self)
 	//liqapp_log("x11overlay refresh begin wh(%i,%i) ",self->yuv_image->width, self->yuv_image->height);
 	if(!self->yuv_shminfo_attached) return 0;
 	
-    //liqcliprect_drawcolorcube( liqcanvas_getcliprect(), 0,0, self->yuv_image->width, self->yuv_image->height,128);
-
+   // liqcliprect_drawcolorcube( liqcanvas_getcliprect(), 0,0, self->yuv_image->width, self->yuv_image->height,128);
+	//liqapp_sleep(1000);
 	int res=0;
 	
 //	if(self->yuv_image->width==480 && self->yuv_image->height==480)
@@ -380,3 +446,8 @@ unsigned int nv = 0x00000000;
 	}
 	return 0;
 }
+
+#ifdef __cplusplus
+}
+#endif
+
