@@ -5,6 +5,8 @@
 
 #include "liqcell.h"
 #include "liqcell_easypaint.h"
+#include "liqaccel.h"
+#include "liqapp_prefs.h"
 #include "vgraph.h"
 
 // virtual graphics and drawing
@@ -18,7 +20,9 @@
 #include "liqcliprect.h"
 #include "liqcell.h"
 	
-	
+#ifdef __cplusplus
+extern "C" {
+#endif	
 	
 	
 
@@ -87,8 +91,28 @@ liqcliprect *vgraph_getcliprect(      vgraph *self)
 
 void    vgraph_convert_target2window(vgraph *self, int tx,int ty,  int *wx, int *wy)
 {
+	
+	
+	
+	
 	if(self->targetw && self->targeth && self->windoww && self->windowh)
 	{
+
+		//ROTATEPATCHPOINT set isportrait as required
+		int isportrait = (self->windowh > self->windoww) && ((self->targetx==0 && self->targety==0)) && (canvas.rotation_angle==0);
+		
+		if((isportrait))
+		{
+			// auto portrait mode ..
+			*wx = ((self->targeth-1) - (ty - self->targety)) * self->windoww / self->targeth;
+			*wy = (                    (tx - self->targetx)) * self->windowh / self->targetw;
+			
+			//liqapp_log("convert from (%3d,%3d)",tx,ty);
+			//liqapp_log("convert to   (%3d,%3d)",*wx,*wy);
+			return;
+		}
+		
+		
 		int x = ((tx - self->scalex) * self->windoww / self->scalew);
 		int y = ((ty - self->scaley) * self->windowh / self->scaleh);
 		*wx=x;
@@ -137,6 +161,16 @@ static float calcaspect(int captionw,int captionh,int availw,int availh)
 }
 
 
+static void vgraph_font_setscale(vgraph *self)
+{
+	float a,b;
+	a=(float)self->scalew/(float)self->windoww;
+	b=(float)self->scaleh/(float)self->windowh;
+	//liqapp_log("vgraph_font_setscale   a= %3.3f b=%3.3f  scale %d,%d  win %d,%d",a,b,self->scalew,self->scaleh, self->windoww,self->windowh);
+	if(self->font) liqfont_setview(self->font,a,b);
+}
+
+
 static void vgraph_recalc(vgraph *self)
 {
 	// recalculate required settings to sit window neatly within target
@@ -161,7 +195,49 @@ static void vgraph_recalc(vgraph *self)
 			self->scaley = self->targety;
 			
 		}
-	/*	
+		
+		vgraph_font_setscale(self);
+
+
+	/*
+#ifdef HASWINDOW
+if(self->window)
+{
+		liqapp_log("scale.WIN %s xy(%d,%d),wh(%d,%d)",self->window->name,
+													  self->window->x,
+													  self->window->y,
+													  self->window->w,
+													  self->window->h);
+}
+#endif
+		liqapp_log("scale.win %i,%i",self->windoww,self->windowh);
+		liqapp_log("scale.tar %i,%i",self->targetw,self->targeth);
+		liqapp_log("scale.sxy %i,%i",self->scalex,self->scaley);
+		liqapp_log("scale.swh %i,%i",self->scalew,self->scaleh);
+
+
+		new batch of tests :)
+		
+		// designed for landscape
+			02:03:10 [lcuk] scale.WIN liqbook xy(0,0),wh(800,480)
+			02:03:10 [lcuk] scale.win 800,480
+			02:03:10 [lcuk] scale.tar 800,480
+			02:03:10 [lcuk] scale.sxy 0,0
+			02:03:10 [lcuk] scale.swh 800,480
+
+		// designed for portrait
+			02:03:12 [lcuk] scale.WIN liqbookreader xy(0,0),wh(480,800)
+			02:03:12 [lcuk] scale.win 480,800
+			02:03:12 [lcuk] scale.tar 800,480
+			02:03:12 [lcuk] scale.sxy 256,0
+			02:03:12 [lcuk] scale.swh 288,480
+			
+		// i need to recognise portrait and return mouse coordinate conversion for them
+		
+
+
+
+		
 		// 20090621_193038 lcuk : no need for all this anymore :)
 		
 		liqapp_log("scale.win %i,%i",self->windoww,self->windowh);
@@ -268,6 +344,7 @@ int		vgraph_setwindow(   vgraph *self, liqcell *window )// int xs,int ys,    int
 {
 	if(window)
 	{
+		//self->window = liqcell_hold(window);
 		self->windowx=window->x;
 		self->windowy=window->y;
 		self->windoww=window->w;
@@ -275,6 +352,8 @@ int		vgraph_setwindow(   vgraph *self, liqcell *window )// int xs,int ys,    int
 	}
 	else
 	{
+		//if(self->window) liqcell_release(self->window);
+		//self->window = NULL;
 		self->windowx=0;
 		self->windowy=0;
 		self->windoww=0;
@@ -287,6 +366,9 @@ int		vgraph_setwindow(   vgraph *self, liqcell *window )// int xs,int ys,    int
 
 int		vgraph_setwindow_coord(     		vgraph *self, int x,int y,    int w,int h )
 {
+	//if(self->window) liqcell_release(self->window);
+	//self->window = NULL;
+		
 	self->windowx=x;
 	self->windowy=y;
 	self->windoww=w;
@@ -332,7 +414,11 @@ int		vgraph_setfont(        vgraph *self, liqfont *font)			//  char *fontname, i
 		self->font=NULL;
 	}
 	
-	if(font)  self->font = liqfont_hold(font);
+	if(font)
+	{
+		self->font = liqfont_hold(font);
+		vgraph_font_setscale(self);
+	}
 	return 0;
 }
 
@@ -422,9 +508,7 @@ int		vgraph_drawgreycol(   	    	vgraph *self, int x, int y, int w,int h    )
 	h = (h * self->scaleh / self->windowh);
 	
 	//liqapp_log("draw.greycol.use %i,%i,%i,%i",x,y,w,h);
-
-	unsigned char *yuva = (unsigned char *)&self->pencolor;
-	liqcliprect_drawgreycol( vgraph_getcliprect(self),   x,y,   w,h,    yuva[0] );
+	liqcliprect_drawgreycol( vgraph_getcliprect(self),   x,y,   w,h);
 
 	return 0;    
 }
@@ -475,6 +559,26 @@ int		vgraph_drawrectwash(       vgraph *self, int x, int y, int w,int h       )
 	liqcliprect_drawboxwashcolor( vgraph_getcliprect(self),   x,y,   w,h,    yuva[1],yuva[2] );
 	return 0;
 }
+int		vgraph_drawrectfadeoutcolor(       vgraph *self, int x, int y, int w,int h       )
+{
+	
+	//liqapp_log("draw.rect.in  %i,%i,%i,%i",x,y,w,h);
+	
+	x = self->scalex + (x * self->scalew / self->windoww);
+	y = self->scaley + (y * self->scaleh / self->windowh);
+	w = (w * self->scalew / self->windoww);
+	h = (h * self->scaleh / self->windowh);
+	
+	
+	
+	//liqapp_log("draw.rect.use %i,%i,%i,%i",x,y,w,h);
+	
+	unsigned char *yuva = (unsigned char *)&self->backcolor;
+	//liqcliprect_drawboxwashcolor( vgraph_getcliprect(self),   x,y,   w,h,    yuva[1],yuva[2] );
+	liqcliprect_drawboxfadeoutcolor(vgraph_getcliprect(self) ,x,y,   w,h,   yuva[0],yuva[1], yuva[2],yuva[3] );
+	return 0;
+}
+
 
 
 
@@ -531,6 +635,17 @@ for(idx=0;idx<5;idx++)
 int		vgraph_drawtext(       vgraph *self, int x, int y, char *text        )
 {
 	if(!self->font)return -1;
+	if(!text)return -1;
+	if(!*text) return 0;
+
+	x = self->scalex + (x * self->scalew / self->windoww);
+	y = self->scaley + (y * self->scaleh / self->windowh);
+	//w = (w * self->scalew / self->windoww);
+	//h = (h * self->scaleh / self->windowh);
+	
+	unsigned char *yuva = (unsigned char *)&self->pencolor;
+	
+	liqcliprect_drawtext_color( vgraph_getcliprect(self),self->font,   x,y, text,  yuva[0],yuva[1],yuva[2]);
 	
 	return 0;
 }
@@ -643,19 +758,75 @@ int		vgraph_drawcell(      vgraph *self, int x, int y, int w,int h , liqcell *ce
 {
 	//liqapp_log("draw.cell.in  %i,%i,%i,%i   %s",x,y,w,h,cell->name);
 	
-	x = self->scalex + (x * self->scalew / self->windoww);
-	y = self->scaley + (y * self->scaleh / self->windowh);
-	w = (w * self->scalew / self->windoww);
-	h = (h * self->scaleh / self->windowh);
+
 	
+
+	//ROTATEPATCHPOINT set is portrait as required
+	int isportrait = (cell->h > cell->w) && ((x==0 && y==0)) && (canvas.rotation_angle==0);
 		
-	//liqapp_log("draw.cell.use %i,%i,%i,%i",x,y,w,h);
+	if( isportrait  )// && (aax < -200 ) )
+	{		
+		// autorotate...
+		// testing potential autorotation patch
+		// this will only work on root level display elements
+		// its very hackish and example based
+		
+		//liqapp_log("vgraph_drawcell autorot strt xy(%d,%d),wh(%d,%d) %s",x,y,w,h,cell->name);
+		static liqimage *img = NULL;
+		if(img)
+		{
+			if(img->width == liqcanvas_getheight() && img->height == liqcanvas_getwidth())
+			{
+				// ok to keep cached
+			}
+			else
+			{
+				// renew
+				liqimage_release(img);
+				img=NULL;
+			}
+		}
+		if(img==NULL)
+		{
+			//liqapp_log("vgraph_drawcell autorot alloc");
+			img = liqimage_newatsize(liqcanvas_getheight(), liqcanvas_getwidth(),0);
+		}
+		liqcliprect *cr = liqcliprect_newfromimage(img);
+		//liqcliprect_drawtext(cr,doc->displayfont,0,y,dline->linedata);
+		//xsurface_drawrectwash_uv(img,0,0,480,800,128,128);
+		
+		//liqapp_log("vgraph_drawcell autorot run  xy(%d,%d),wh(%d,%d) %s",x,y,w,h,cell->name);
+		//y = self->scalex + (y * self->scalew / self->windoww);
+		//x = self->scaley + (x * self->scaleh / self->windowh);
+		//h = (h * self->scalew / self->windoww);
+		//w = (w * self->scaleh / self->windowh);
+		
+		liqcliprect_drawclear(cr,0,128,128);
+		if(h>w)
+			liqcell_easypaint(cell,cr,x,y,w,h);
+		else
+			liqcell_easypaint(cell,cr,x,y,h,w);
+		liqimage_rotate( liqcanvas_getsurface(), img, 90 );
+		liqcliprect_release(cr);
+		
+		//liqapp_log("vgraph_drawcell autorot done xy(%d,%d),wh(%d,%d) %s",x,y,w,h,cell->name);
+	}
+	else
+	{
+
+		x = self->scalex + (x * self->scalew / self->windoww);
+		y = self->scaley + (y * self->scaleh / self->windowh);
+		w = (w * self->scalew / self->windoww);
+		h = (h * self->scaleh / self->windowh);
+			
+		liqcell_easypaint(cell,vgraph_getcliprect(self),x,y,w,h);
+	}
 	
 	
 	
-	liqcell_easypaint(cell,vgraph_getcliprect(self),x,y,w,h);
-	
-	
+
+	//liqapp_log("draw.cell.out  %i,%i,%i,%i   %s",x,y,w,h,cell->name);
+		
 	return 0;
 }
 
@@ -679,3 +850,8 @@ int		vgraph_pget(      vgraph *self, int x, int y,unsigned char *grey,unsigned c
 	liqcliprect_drawpgetcolor( vgraph_getcliprect(self),   x,y,       grey,u,v );
 	return 0;
 }
+
+#ifdef __cplusplus
+}
+#endif
+
